==> seedsui-react-2.6.2.tgz: package/es/Star/Star.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Star = (_temp = _class = function (_Component) {
  _inherits(Star, _Component);

  function Star(props) {
    _classCallCheck(this, Star);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.onClick = function (e) {
      if (_this.props.onClick) {
        _this.props.onClick(Object.getArgs(e, _this.props.args));
      }
    };

    return _this;
  }

  Star.prototype.render = function render() {
    var _props = this.props,
        args = _props.args,
        className = _props.className,
        onClick = _props.onClick,
        others = _objectWithoutProperties(_props, ['args', 'className', 'onClick']);

    return React.createElement('i', _extends({ className: 'star' + (className ? ' ' + className : '') }, others, { onClick: this.onClick }));
  };

  return Star;
}(Component), _class.defaultProps = {
  args: null
}, _temp);
export { Star as default };
Star.propTypes = process.env.NODE_ENV !== "production" ? {
  args: PropTypes.any,
  className: PropTypes.string,
  onClick: PropTypes.func
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Star/Star.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';

var Star = (_temp = _class = function (_Component) {
  _inherits(Star, _Component);

  function Star(props) {
    _classCallCheck(this, Star);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Star.prototype.render = function render() {
    var others = _objectWithoutProperties(this.props, []);

    return React.createElement('i', _extends({}, others, { className: 'star' + (others.className ? ' ' + others.className : '') }));
  };

  return Star;
}(Component), _class.defaultProps = {}, _temp);
export { Star as default };
Star.propTypes = process.env.NODE_ENV !== "production" ? {} : {};
